@@ -3,14 +3,15 @@ from __future__ import print_function
 import json
 import logging
 
-from argh import *
-from ghtools.api import GithubAPIClient
+from argh import ArghParser, arg
+from ghtools import cli
+from ghtools.github.repo import Repo
 
 log = logging.getLogger(__name__)
 parser = ArghParser(description="Set commit/branch build status")
 
-@arg('-n', '--nickname', default='public', help='GitHub instance nickname')
-@arg('repo', help='Repository name (e.g. "joebloggs/myapp")')
+
+@arg('repo', help='Repository identifier (e.g. joebloggs/myapp, enterprise:mycorp/myrepo)')
 @arg('sha', help='Git SHA1')
 @arg('state', help='State to attach', choices=['pending', 'success', 'error', 'failure'])
 @arg('-d', '--description', help='Status description')
@@ -19,9 +20,9 @@ def status(args):
     """
     Set build status for a commit on GitHub
     """
-    c = GithubAPIClient(nickname=args.nickname)
+    repo = Repo(args.repo)
 
-    payload = { 'state': args.state }
+    payload = {'state': args.state}
 
     if args.description is not None:
         payload['description'] = args.description
@@ -29,13 +30,15 @@ def status(args):
     if args.url is not None:
         payload['target_url'] = args.url
 
-    res = c.post('/repos/{0}/statuses/{1}'.format(args.repo, args.sha), data=payload)
+    with cli.catch_api_errors():
+        res = repo.set_build_status(args.sha, payload)
 
-    print(json.dumps(res.json, indent=2))
+    print(json.dumps(res.json(), indent=2))
+parser.set_default_command(status)
 
 
 def main():
-    dispatch_command(status)
+    parser.dispatch()
 
 if __name__ == '__main__':
     main()
